3.2.2. pypago.grid.create_grid — PyPAGO 1.0.1 documentation

# 3.2.2. pypago.grid.create_grid

`pypago.grid.` `create_grid`(coord, jmin=None, jmax=None, imin=None, imax=None)

  Returns a Grid instance associated with the input coord argument. If it is a pypago.coord.GfdlCoords object, then it returns a `pypago.grid.GfdlGrid` object. Else, it returns a `pypago.grid.CommonGrid` object.

  Parameters: | jmin (int) – Index of the southernmost point of the subdomain jmax (int) – Index of the northernmost point of the subdomain imin (int) – Index of the westernmost point of the subdomain imax (int) – Index of the easternnmost point of the subdomain

  :param `pypago.coords.Coords` coord: Coordinate object
    associated with the grid file (longitude, latitude, mask of the entire domain, used in the file extraction)